@@ -647,9 +647,12 @@ mod tests {
     #[test]
     fn it_recognizes_escaped_strings() {
         let inputs = [
-            "\"foo \\\" JOIN bar\"",
-            "'foo \\' JOIN bar'",
-            "`foo `` JOIN bar`",
+            r#""foo \" JOIN bar""#,
+            r#"'foo \' JOIN bar'"#,
+            r#"`foo `` JOIN bar`"#,
+            r#"'foo '' JOIN bar'"#,
+            r#"'two households"'"#,
+            r#"'two households'''"#,
         ];
         let options = FormatOptions::default();
         for input in &inputs {
@@ -731,8 +734,10 @@ mod tests {
     #[test]
     fn it_converts_keywords_to_uppercase_when_option_passed_in() {
         let input = "select distinct * frOM foo left join bar WHERe cola > 1 and colb = 3";
-        let mut options = FormatOptions::default();
-        options.uppercase = true;
+        let options = FormatOptions {
+            uppercase: true,
+            ..FormatOptions::default()
+        };
         let expected = indoc!(
             "
             SELECT
@@ -751,8 +756,10 @@ mod tests {
     #[test]
     fn it_line_breaks_between_queries_with_config() {
         let input = "SELECT * FROM foo; SELECT * FROM bar;";
-        let mut options = FormatOptions::default();
-        options.lines_between_queries = 2;
+        let options = FormatOptions {
+            lines_between_queries: 2,
+            ..FormatOptions::default()
+        };
         let expected = indoc!(
             "
             SELECT
@@ -1016,6 +1023,8 @@ mod tests {
             format(input, &QueryParams::Indexed(params), options),
             expected
         );
+
+        format("?62666666121266666612", &QueryParams::None, options);
     }
 
     #[test]
